<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common" xmlns:tei="http://www.tei-c.org/ns/1.0"
  exclude-result-prefixes="exsl">

  <xsl:param name="html-title">Glosarček izrazov konjeniške terminologije</xsl:param>

  <xsl:output method="html" encoding="utf-8" indent="yes"/>
  <xsl:key name="term" match="term" use="normalize-space(text())"/>

  <xsl:template match="/">
    <HTML>
      <HEAD>
        <TITLE>
          <xsl:value-of select="$html-title"/>
        </TITLE>
        <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
        <STYLE TYPE="text/css">
          <xsl:comment> H1, H2 { color: green } span.term { font-size: 130%; } </xsl:comment>
        </STYLE>
      </HEAD>
      <BODY>
        <H1>
          <xsl:value-of select="$html-title"/>
        </H1>

	<P>Glosarček je nastal kot del magistrskega dela Helene Plahute na Univerzi v Novi Gorici. 
	<BR/>Mentor: <A href="http://nl.ijs.si/et/">Tomaž Erjavec</A>, IJS</P>

        <H2>Kazalo po področjih</H2>
        <UL>
          <xsl:for-each select="//conceptGrp/descripGrp/descrip[@type='subject']">
            <xsl:sort/>
            <xsl:variable name="subject" select="."/>
            <xsl:if test="not(following::descrip[@type='subject'][. = $subject])">
              <LI>
                <B>
                  <xsl:value-of select="$subject"/>
                </B>
                <xsl:text>: </xsl:text>
                <xsl:for-each
                  select="//term[ancestor::conceptGrp/descripGrp/descrip[@type='subject'] = $subject]">
                  <A href="#{generate-id(.)}">
                    <xsl:value-of select="."/>
                  </A>
                  <xsl:if test="following::term[ancestor::conceptGrp/descripGrp/descrip[@type='subject'] = $subject]">,</xsl:if>
                  <xsl:text> </xsl:text>
                </xsl:for-each>
              </LI>
            </xsl:if>
          </xsl:for-each>
        </UL>
        <H2>Glosar</H2>
        <xsl:apply-templates select="//term">
          <xsl:sort/>
        </xsl:apply-templates>
        <HR/>
      </BODY>
    </HTML>
  </xsl:template>

  <xsl:template match="term">
    <xsl:variable name="id" select="generate-id(.)"/>
    <div class="term">
      <a name="{$id}">
        <b>
          <span class="term">
            <xsl:value-of select="."/>
          </span>
        </b>
      </a>
      <xsl:if test="../descripGrp/descrip[@type='note']">
	<xsl:text> (</xsl:text>	
	<xsl:value-of select="../descripGrp/descrip[@type='note']"/>
	<xsl:text>) </xsl:text>	
      </xsl:if>
      <xsl:for-each select="ancestor::conceptGrp/descripGrp/descrip[@type='subject']">
        <xsl:text> [</xsl:text>
        <span class="subject">
          <xsl:apply-templates/>
        </span>
        <xsl:text>]</xsl:text>
      </xsl:for-each>
      <xsl:if test="not(../preceding-sibling::termGrp)">
        <p>
          <b class="Definition">
            <xsl:apply-templates
              select="ancestor::languageGrp/descripGrp/descrip[@type='definition']"/>
          </b>
        </p>
        <xsl:if test="ancestor::languageGrp/descripGrp/descrip[@type='Note']">
          <xsl:apply-templates select="ancestor::languageGrp/descripGrp/descrip[@type='Note']"/>
        </xsl:if>
      </xsl:if>
      <p>
        <!--xsl:text>Primeri uporabe:</xsl:text-->
        <ul>
          <xsl:for-each select="following-sibling::descripGrp[descrip[@type='context']]">
            <li>
              <xsl:value-of select="descrip[@type='context']"/>
              <xsl:text> [</xsl:text>
              <xsl:value-of select="following-sibling::descripGrp/descrip[@type='source']"/>
              <xsl:text>]</xsl:text>
            </li>
          </xsl:for-each>
        </ul>
      </p>
      <p>
        <xsl:variable name="last"
          select="generate-id(ancestor::languageGrp/termGrp/term[generate-id(.) != $id][2])"/>
        <xsl:for-each select="ancestor::languageGrp/termGrp/term[generate-id(.) != $id]">
          <xsl:text> → </xsl:text>
          <xsl:variable name="cross-id" select="generate-id(.)"/>
          <a href="#{$cross-id}">
            <i class="cross-ref">
              <xsl:choose>
                <xsl:when test="not(../preceding-sibling::termGrp)">
                  <b>
                    <xsl:value-of select="."/>
                  </b>
                </xsl:when>
                <xsl:otherwise>
                  <xsl:value-of select="."/>
                </xsl:otherwise>
              </xsl:choose>
            </i>
          </a>
          <!--xsl:if test="$cross-id = $last">XXXXXXXXXXXX</xsl:if-->
          <br/>
        </xsl:for-each>
      </p>
      <hr/>
    </div>
  </xsl:template>

  <xsl:template match="descrip[@type='Note']">
    <p>
      <span class="Note">
        <xsl:apply-templates/>
      </span>
    </p>
  </xsl:template>
  <xsl:template match="xref[@Tlink]">
    <a>
      <xsl:variable name="term" select="substring-after(@Tlink,':')"/>
      <!--xsl:variable name="term" select="normalize-space(.)"/-->
      <xsl:attribute name="href">
        <xsl:text>#</xsl:text>
        <xsl:value-of select="generate-id(key('term',$term))"/>
      </xsl:attribute>
      <xsl:value-of select="."/>
      <xsl:if test="not(normalize-space($term))">???</xsl:if>
    </a>
  </xsl:template>
  <xsl:template match="text()">
    <xsl:variable name="p">http://</xsl:variable>
    <xsl:choose>
      <xsl:when test="contains(.,$p)">
        <xsl:value-of select="substring-before(.,$p)"/>
        <xsl:variable name="tmp" select="substring-after(.,$p)"/>
        <xsl:variable name="url" select="concat($p,substring-before($tmp,' '))"/>
        <xsl:variable name="rest" select="substring-after($tmp,' ')"/>
        <a href="{$url}">
          <xsl:value-of select="$url"/>
        </a>
        <xsl:value-of select="$rest"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="."/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>
